==> prestashop_1.5.0.15.zip: prestashop/modules/newsletter/translations/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{newsletter}prestashop>newsletter_ffb7e666a70151215b4c55c6268d7d72'] = 'Newsletter';
$_MODULE['<{newsletter}prestashop>newsletter_804a924e464fd21ed92f820224c4091d'] = 'Erzeugt eine .CSV-Datei für Massenmailings';
$_MODULE['<{newsletter}prestashop>newsletter_c3987e4cac14a8456515f0d200da04ee'] = 'Alle Länder';
$_MODULE['<{newsletter}prestashop>newsletter_fa01fd956e87307bce4c90a0de9b0437'] = 'Kundenländer';
$_MODULE['<{newsletter}prestashop>newsletter_c0859b0a5241dff468da2a9a93c3284f'] = 'Betreiben Sie einen Filter für das Kundenland.';
$_MODULE['<{newsletter}prestashop>newsletter_2198f293f5e1e95dddeff819fbca0975'] = 'Newsletter-Abonnenten';
$_MODULE['<{newsletter}prestashop>newsletter_99006a61d48499231e1be92241cf772a'] = 'Newsletter-Abonnenten Filtern.';
$_MODULE['<{newsletter}prestashop>newsletter_7e3a51a56ddd2846e21c33f05e0aea6f'] = 'Alle Kunden';
$_MODULE['<{newsletter}prestashop>newsletter_39f7a3e2b56e9bfd753ba6325533a127'] = 'Abonnenten';
$_MODULE['<{newsletter}prestashop>newsletter_011d8c5d94f729f013963d856cd78745'] = 'Nicht-Abonnenten';
$_MODULE['<{newsletter}prestashop>newsletter_793ee192a9124cd6f529460eef17d3e5'] = 'Opt-in-Abonnenten';
$_MODULE['<{newsletter}prestashop>newsletter_7b15c043d66fecc45c8752592aa38e38'] = 'Opt-in Abonnenten filtern.';
$_MODULE['<{newsletter}prestashop>newsletter_82e5e0bc0f9c776c98253d569c111c0f'] = 'Keine Kunden mit diesen Filtern gefunden!';
$_MODULE['<{newsletter}prestashop>newsletter_48e3d5f66961b621c78f709afcd7d437'] = 'Laden Sie die Datei herunter';
$_MODULE['<{newsletter}prestashop>newsletter_faa1115fbab933e7178ee43ce1590977'] = 'ACHTUNG: Wenn Sie diese CSV-Datei mit Excel zu öffnen versuchen, vergessen Sie nicht, den UTF-8 Code zu wählen, sonst können seltsame Zeichen erscheinen';
$_MODULE['<{newsletter}prestashop>newsletter_81573e0ea79138f02fd2cee94786d7e9'] = 'Fehler: kann nicht schreiben';
$_MODULE['<{newsletter}prestashop>newsletter_8d550e9bf69bfc7a09be6eeb1622ae23'] = 'Es gibt zwei Arten für dieses Modul:';
$_MODULE['<{newsletter}prestashop>newsletter_23e8f8a55548b88bfbdcd1f6ba26a010'] = 'Personen, die den Newsletter über den BlockNewsletter Block im Front-Office abonniert haben.';
$_MODULE['<{newsletter}prestashop>newsletter_27d1ec406fd2baf49d03f81a4bb41122'] = 'Dies wird eine Liste mit E-Mails von Personen, die Ihren Shop besuchen und nicht Kunden werden, sondern Ihren Newsletter erhalten wollen. Mit der Benutzung der untenstehenden Liste \"Export Newsletter Abonnenten\"wird eine . CSV-Datei generiert, die auf den BlockNewsletter Abonnenten-Daten basiert .';
$_MODULE['<{newsletter}prestashop>newsletter_74ca54506cdbc82e3aa763ba91b8fa39'] = 'Kunden, die \"ja\" angeklickt haben, um einen Newsletter in ihrem Kundenprofil zu erhalten.';
$_MODULE['<{newsletter}prestashop>newsletter_1aa14f5a6423dbde1ef2cfe4734980b4'] = 'Der Abschnitt \"Export Kunden\" unten filtert die Kunden, denen Sie einen Newsletter schicken möchten.';
$_MODULE['<{newsletter}prestashop>newsletter_7f5c4d54d8602ab7234a715a2a10b98e'] = 'Export Newsletter-Abonnenten';
$_MODULE['<{newsletter}prestashop>newsletter_a60401e616125189d78605b2ddd7ff45'] = 'Erzeugen Sie eine. CSV-Datei aus BlockNewsletter Abonnenten-Daten.';
$_MODULE['<{newsletter}prestashop>newsletter_dbb392a2dc9b38722e69f6032faea73e'] = '.CSV-Datei exportieren';
$_MODULE['<{newsletter}prestashop>newsletter_4713ef5f2d6fc1e8f088c850e696a04b'] = 'Kunden exportieren';
$_MODULE['<{newsletter}prestashop>newsletter_2a96d838a5e89b86792669f0ab422987'] = '.CSV-Datei aus Kunden-Konto-Daten generieren.';

==> prestashop_1.5.1.0.zip: prestashop/modules/newsletter/translations/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{newsletter}prestashop>newsletter_ffb7e666a70151215b4c55c6268d7d72'] = 'Newsletter';
$_MODULE['<{newsletter}prestashop>newsletter_804a924e464fd21ed92f820224c4091d'] = 'Erzeugt eine .CSV-Datei für Massenmailings';
$_MODULE['<{newsletter}prestashop>newsletter_c3987e4cac14a8456515f0d200da04ee'] = 'Alle Länder';
$_MODULE['<{newsletter}prestashop>newsletter_fa01fd956e87307bce4c90a0de9b0437'] = 'Kundenländer';
$_MODULE['<{newsletter}prestashop>newsletter_c0859b0a5241dff468da2a9a93c3284f'] = 'Betreiben Sie einen Filter für das Kundenland.';
$_MODULE['<{newsletter}prestashop>newsletter_2198f293f5e1e95dddeff819fbca0975'] = 'Newsletter-Abonnenten';
$_MODULE['<{newsletter}prestashop>newsletter_99006a61d48499231e1be92241cf772a'] = 'Newsletter-Abonnenten Filtern.';
$_MODULE['<{newsletter}prestashop>newsletter_7e3a51a56ddd2846e21c33f05e0aea6f'] = 'Alle Kunden';
$_MODULE['<{newsletter}prestashop>newsletter_39f7a3e2b56e9bfd753ba6325533a127'] = 'Abonnenten';
$_MODULE['<{newsletter}prestashop>newsletter_011d8c5d94f729f013963d856cd78745'] = 'Nicht-Abonnenten';
$_MODULE['<{newsletter}prestashop>newsletter_793ee192a9124cd6f529460eef17d3e5'] = 'Opt-in-Abonnenten';
$_MODULE['<{newsletter}prestashop>newsletter_7b15c043d66fecc45c8752592aa38e38'] = 'Opt-in Abonnenten filtern.';
$_MODULE['<{newsletter}prestashop>newsletter_82e5e0bc0f9c776c98253d569c111c0f'] = 'Keine Kunden mit diesen Filtern gefunden!';
$_MODULE['<{newsletter}prestashop>newsletter_04e7c39a16e4d89fe9c3861af82ececa'] = 'Die .CSV-Datei wurde erfolgreich exportiert. (%d Kunden vorhanden)';
$_MODULE['<{newsletter}prestashop>newsletter_48e3d5f66961b621c78f709afcd7d437'] = 'Laden Sie die Datei herunter';
$_MODULE['<{newsletter}prestashop>newsletter_faa1115fbab933e7178ee43ce1590977'] = 'ACHTUNG: Wenn Sie diese CSV-Datei mit Excel zu öffnen versuchen, vergessen Sie nicht, den UTF-8 Code zu wählen, sonst können seltsame Zeichen erscheinen';
$_MODULE['<{newsletter}prestashop>newsletter_81573e0ea79138f02fd2cee94786d7e9'] = 'Fehler: kann nicht schreiben';
$_MODULE['<{newsletter}prestashop>newsletter_8d550e9bf69bfc7a09be6eeb1622ae23'] = 'Es gibt zwei Arten für dieses Modul:';
$_MODULE['<{newsletter}prestashop>newsletter_23e8f8a55548b88bfbdcd1f6ba26a010'] = 'Personen, die den Newsletter über den BlockNewsletter Block im Front-Office abonniert haben.';
$_MODULE['<{newsletter}prestashop>newsletter_27d1ec406fd2baf49d03f81a4bb41122'] = 'Dies wird eine Liste mit E-Mails von Personen, die Ihren Shop besuchen und nicht Kunden werden, sondern Ihren Newsletter erhalten wollen. Mit der Benutzung der untenstehenden Liste \"Export Newsletter Abonnenten\"wird eine . CSV-Datei generiert, die auf den BlockNewsletter Abonnenten-Daten basiert .';
$_MODULE['<{newsletter}prestashop>newsletter_74ca54506cdbc82e3aa763ba91b8fa39'] = 'Kunden, die \"ja\" angeklickt haben, um einen Newsletter in ihrem Kundenprofil zu erhalten.';
$_MODULE['<{newsletter}prestashop>newsletter_1aa14f5a6423dbde1ef2cfe4734980b4'] = 'Der Abschnitt \"Export Kunden\" unten filtert die Kunden, denen Sie einen Newsletter schicken möchten.';
$_MODULE['<{newsletter}prestashop>newsletter_7f5c4d54d8602ab7234a715a2a10b98e'] = 'Export Newsletter-Abonnenten';
$_MODULE['<{newsletter}prestashop>newsletter_a60401e616125189d78605b2ddd7ff45'] = 'Erzeugen Sie eine. CSV-Datei aus BlockNewsletter Abonnenten-Daten.';
$_MODULE['<{newsletter}prestashop>newsletter_769050278dda5e93374adda37811e413'] = 'Es werden ausschließlich Abonnenten ohne eigenen Account exportiert.';
$_MODULE['<{newsletter}prestashop>newsletter_dbb392a2dc9b38722e69f6032faea73e'] = '.CSV-Datei exportieren';
$_MODULE['<{newsletter}prestashop>newsletter_4713ef5f2d6fc1e8f088c850e696a04b'] = 'Kunden exportieren';
$_MODULE['<{newsletter}prestashop>newsletter_2a96d838a5e89b86792669f0ab422987'] = '.CSV-Datei aus Kunden-Konto-Daten generieren.';
